@@ -2,7 +2,7 @@ package Plack::Request;
 use strict;
 use warnings;
 use 5.008_001;
-our $VERSION = '1.0047';
+our $VERSION = '1.0048';
 
 use HTTP::Headers::Fast;
 use Carp ();
@@ -251,11 +251,6 @@ sub _buffer_length_for {
 
 sub _parse_request_body {
     my $self = shift;
-    if ( !$self->env->{CONTENT_TYPE} ) {
-        $self->env->{'plack.request.body_parameters'} = [];
-        $self->env->{'plack.request.upload'} = Hash::MultiValue->new();
-        return;
-    }
 
     my ($params,$uploads) = $self->request_body_parser->parse($self->env);
     $self->env->{'plack.request.body_parameters'} = $params;
@@ -485,11 +480,20 @@ Shortcut to $req->headers->content_encoding.
 
 =item content_length
 
-Shortcut to $req->headers->content_length.
+Returns the raw value of the Content-Length header.
+
+Before version 0.9925, this method was a shortcut for
+C<< $req->headers->content_length >>.
 
 =item content_type
 
-Shortcut to $req->headers->content_type.
+Returns the raw value of the Content-Type header.
+
+If you want just the MIME type, without any attributes like charset, use
+C<< $req->headers->content_type >>.  See also L<HTTP::Headers/content_type>.
+
+Before version 0.9925, this method was a shortcut for
+C<< $req->headers->content_type >>.
 
 =item header
 
